@@ -30,5 +30,7 @@ if __name__ == '__main__':
         with open(path, "w") as f:
             new_file = whole_file.replace(obtain_line, "     \"feagi_host\": \"" + args['ip'] + "\",\n")
             f.write(new_file)
+    new_path = current_path[0] + "/verify.sh "
+    subprocess.run([new_path, "arguments"], shell=True)
     from feagi_agent_freenove import controller as freenove_smartcar_controller
     freenove_smartcar_controller.main()
